@@ -23,8 +23,10 @@ module Dalli
 
     attr_accessor :servers, :continuum
 
-    def initialize(servers, options)
-      @servers = servers
+    def initialize(servers_arg, protocol_implementation, options)
+      @servers = servers_arg.map do |s|
+        protocol_implementation.new(s, options)
+      end
       @continuum = nil
       @continuum = build_continuum(servers) if servers.size > 1
 
@@ -79,7 +81,7 @@ module Dalli
       end
     end
 
-    def flush_multi_responses
+    def pipeline_consume_and_ignore_responses
       @servers.each do |s|
         s.request(:noop)
       rescue Dalli::NetworkError
@@ -92,6 +94,10 @@ module Dalli
       @servers.first.socket_timeout
     end
 
+    def close
+      @servers.each(&:close)
+    end
+
     private
 
     def threadsafe!
